Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/charlcd_mono_simpletest.py
    :caption: examples/charlcd_mono_simpletest.py
    :linenos:

.. literalinclude:: ../examples/charlcd_rgb_simpletest.py
    :caption: examples/charlcd_rgb_simpletest.py
    :linenos:

.. literalinclude:: ../examples/charlcd_i2c_mono_simpletest.py
    :caption: examples/charlcd_i2c_mono_simpletest.py
    :linenos:

.. literalinclude:: ../examples/charlcd_spi_mono_simpletest.py
    :caption: examples/charlcd_spi_mono_simpletest.py
    :linenos:

.. literalinclude:: ../examples/charlcd_keypad_simpletest.py
    :caption: examples/charlcd_keypad_simpletest.py
    :linenos:
